@@ -1,5 +1,5 @@
 """Top-level package for kubify."""
 
-__author__ = """kubify"""
+__author__ = "kubify"
 __email__ = "w@kubify.com"
-__version__ = "9003.1.0"
+__version__ = "9004.0.0"
